@@ -8,7 +8,7 @@ function(data=NULL, model=NULL, addCosts=NULL) {
         predictions = model$predictions
     } else {
         if(length(data$test) > 0) {
-            predictions = do.call(rbind, lapply(data$test, function(x) {
+            predictions = rbind.fill(lapply(data$test, function(x) {
                 data$data = data$data[x,]
                 data$best = data$best[x]
                 model(data)
@@ -35,3 +35,5 @@ function(data=NULL, model=NULL, addCosts=NULL) {
     agg = aggregate(as.formula(paste("score~", paste(c(data$ids, "iteration"), sep="+", collapse="+"))), predictions, function(ss) { ss[1] })
     agg$score
 }
+class(misclassificationPenalties) = "llama.metric"
+attr(misclassificationPenalties, "minimize") = TRUE
